@@ -2,16 +2,14 @@
 ( cd usr/bin ; ln -sf libpng12-config libpng-config )
 ( cd usr/lib64 ; rm -rf libpng.so )
 ( cd usr/lib64 ; ln -sf libpng.so.3 libpng.so )
-( cd usr/lib64/pkgconfig ; rm -rf libpng.pc )
-( cd usr/lib64/pkgconfig ; ln -sf libpng12.pc libpng.pc )
 ( cd usr/lib64 ; rm -rf libpng12.so )
 ( cd usr/lib64 ; ln -sf libpng12.so.0 libpng12.so )
 ( cd usr/lib64 ; rm -rf libpng.so.0 )
 ( cd usr/lib64 ; ln -sf libpng.so.3 libpng.so.0 )
 ( cd usr/lib64 ; rm -rf libpng.so.3 )
-( cd usr/lib64 ; ln -sf libpng.so.3.1.2.27 libpng.so.3 )
+( cd usr/lib64 ; ln -sf libpng.so.3.1.2.32 libpng.so.3 )
 ( cd usr/lib64 ; rm -rf libpng12.so.0 )
-( cd usr/lib64 ; ln -sf libpng12.so.0.1.2.27 libpng12.so.0 )
+( cd usr/lib64 ; ln -sf libpng12.so.0.1.2.32 libpng12.so.0 )
 ( cd usr/lib64 ; rm -rf libpng.a )
 ( cd usr/lib64 ; ln -sf libpng12.a libpng.a )
 ( cd usr/include ; rm -rf pngconf.h )
